==> zio-aws-mediatailor_3-5.17.124.3-sources.jar: zio/aws/mediatailor/model/AdMarkerPassthrough.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__boolean
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class AdMarkerPassthrough(enabled: Option[__boolean] = None) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.AdMarkerPassthrough = {
    import AdMarkerPassthrough.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.AdMarkerPassthrough
      .builder()
      .optionallyWith(
        enabled.map(value => __boolean.unwrap(value): java.lang.Boolean)
      )(_.enabled)
      .build()
  }
  def asReadOnly: zio.aws.mediatailor.model.AdMarkerPassthrough.ReadOnly =
    zio.aws.mediatailor.model.AdMarkerPassthrough.wrap(buildAwsValue())
}
object AdMarkerPassthrough {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.AdMarkerPassthrough
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.AdMarkerPassthrough =
      zio.aws.mediatailor.model.AdMarkerPassthrough(enabled.map(value => value))
    def enabled: Option[__boolean]
    def getEnabled: ZIO[Any, AwsError, __boolean] =
      AwsError.unwrapOptionField("enabled", enabled)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.AdMarkerPassthrough
  ) extends zio.aws.mediatailor.model.AdMarkerPassthrough.ReadOnly {
    override val enabled: Option[__boolean] = scala
      .Option(impl.enabled())
      .map(value => zio.aws.mediatailor.model.primitives.__boolean(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.AdMarkerPassthrough
  ): zio.aws.mediatailor.model.AdMarkerPassthrough.ReadOnly = new Wrapper(impl)
}

==> zio-aws-mediatailor_3-5.17.158.3-sources.jar: zio/aws/mediatailor/model/AdMarkerPassthrough.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__boolean
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class AdMarkerPassthrough(enabled: Option[__boolean] = None) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.AdMarkerPassthrough = {
    import AdMarkerPassthrough.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.AdMarkerPassthrough
      .builder()
      .optionallyWith(enabled.map(value => value: java.lang.Boolean))(_.enabled)
      .build()
  }
  def asReadOnly: zio.aws.mediatailor.model.AdMarkerPassthrough.ReadOnly =
    zio.aws.mediatailor.model.AdMarkerPassthrough.wrap(buildAwsValue())
}
object AdMarkerPassthrough {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.AdMarkerPassthrough
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.AdMarkerPassthrough =
      zio.aws.mediatailor.model.AdMarkerPassthrough(enabled.map(value => value))
    def enabled: Option[__boolean]
    def getEnabled: ZIO[Any, AwsError, __boolean] =
      AwsError.unwrapOptionField("enabled", enabled)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.AdMarkerPassthrough
  ) extends zio.aws.mediatailor.model.AdMarkerPassthrough.ReadOnly {
    override val enabled: Option[__boolean] =
      scala.Option(impl.enabled()).map(value => value: __boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.AdMarkerPassthrough
  ): zio.aws.mediatailor.model.AdMarkerPassthrough.ReadOnly = new Wrapper(impl)
}
